AndroidCustomColumns class

Android platform implementation of CustomColumns.

Inheritance

Constructors

AndroidCustomColumns()
const

Properties

createDate String
The creation date column.
no setteroverride
duration String
The duration column.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
height String
The height column.
no setteroverride
id String
The id column.
no setteroverride
isFavorite String
The favorite column.
no setteroverride
mediaType String
The media type column.
no setteroverride
modifiedDate String
The modified date column.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width String
The width column.
no setteroverride

Methods

getValues() List<String>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited