CustomColumns class abstract
A class that contains the names of the columns used in the custom filter.
The names of the columns are different on different platforms. For example,
the width column on Android is width, but on iOS it is pixelWidth.
The definition of the column name can be found in next link:
- Android: https://developer.android.com/reference/android/provider/MediaStore.MediaColumns
- iOS: https://developer.apple.com/documentation/photokit/phasset
Special Columns to see AndroidMediaColumns and DarwinColumns.
Example:
OrderByItem(CustomColumns.base.width, true);
Constructors
- CustomColumns()
-
A class that contains the names of the columns used in the custom filter.
const
Properties
- createDate → String
-
The creation date column.
no setter
- duration → String
-
The duration column.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → String
-
The height column.
no setter
- id → String
-
The id column.
no setter
- isFavorite → String
-
The favorite column.
no setter
- mediaType → String
-
The media type column.
no setter
- modifiedDate → String
-
The modified date column.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → String
-
The width column.
no setter
Methods
-
getValues(
) → List< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- base → CustomColumns
-
The platform columns for the current platform.
final
Static Methods
-
dateColumns(
) → List< String> -
platformValues(
) → List< String> -
values(
) → List< String>
Constants
- android → const AndroidMediaColumns
- The android columns, contains the android specific columns.
- darwin → const DarwinColumns
- The darwin columns, contains the ios and macos specific columns.
- ohos → const AndroidMediaColumns
- The ohos columns, contains the ohos specific columns.
- utils → const ColumnUtils