height property
String
get
height
The height column.
In android, the value of this column maybe null.
In iOS/macOS, the value of this column not null.
Implementation
String get height;
The height column.
In android, the value of this column maybe null.
In iOS/macOS, the value of this column not null.
String get height;