width property
String
get
width
The width column.
In android, the value of this column maybe null.
In iOS/macOS, the value of this column not null.
Implementation
String get width;
The width column.
In android, the value of this column maybe null.
In iOS/macOS, the value of this column not null.
String get width;