DarwinColumns class

A class that contains the names of the columns of the iOS/macOS platform.

About the values mean, please see document of iOS: https://developer.apple.com/documentation/photokit/phasset

Inheritance

Constructors

DarwinColumns()
const

Properties

adjustmentFormatIdentifier String
no setter
createDate String
The creation date column.
no setteroverride
duration String
The duration column.
no setteroverride
hasAdjustments String
no setter
hashCode int
The hash code for this object.
no setterinherited
height String
The height column.
no setteroverride
hidden String
no setter
id String
The id column.
no setteroverride
isFavorite String
The favorite column.
no setteroverride
location String
no setter
mediaSubtypes String
no setter
mediaType String
The media type column.
no setteroverride
modifiedDate String
The modified date column.
no setteroverride
playbackStyle String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceType String
no setter
width String
The width column.
no setteroverride

Methods

getValues() List<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

values() List<String>
override