OhosColumns class

A class that contains the names of the columns used in the custom filter.

About the values mean, please see document of ohos: https://developer.android.com/reference/android/provider/MediaStore

Inheritance

Constructors

OhosColumns()
const

Properties

createDate String
The creation date column.
no setteroverride
dateTaken String
no setter
displayName String
no setter
duration String
The duration column.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
height String
The height column.
no setteroverride
id String
The id column.
no setteroverride
isFavorite String
The favorite column.
no setteroverride
mediaType String
The media type column.
no setteroverride
modifiedDate String
The modified date column.
no setteroverride
orientation String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size String
no setter
title String
no setter
width String
The width column.
no setteroverride

Methods

getValues() List<String>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

values() List<String>
override